==> haskell-tasty-hunit-0.10.0.1-25-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hunit
version: 0.10.0.1
id: tasty-hunit-0.10.0.1-8ubnQp2nCcQCa62i6LTgus
key: tasty-hunit-0.10.0.1-8ubnQp2nCcQCa62i6LTgus
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.
category: Testing
abi: 48805825f87b6561a1147f5c736e4a4f
exposed: True
exposed-modules:
    Test.Tasty.HUnit
hidden-modules: Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-hunit-0.10.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-hunit-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/tasty-hunit-0.10.0.1
hs-libraries: HStasty-hunit-0.10.0.1-8ubnQp2nCcQCa62i6LTgus
depends:
    base-4.11.1.0 tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tasty-1.1.0.3-KUFSSP3U4ny9AQF2XUXxIK=b3b38fe9dbf8881a7eed1fb4b5bf8074
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=c76ca250c7cf6b5c2ee744c15760c93f
haddock-interfaces: /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html: /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hunit-0.10.0.1-29-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hunit
version: 0.10.0.1
id: tasty-hunit-0.10.0.1-A8l0f8Sa1t1GLyHAXqb4Vv
key: tasty-hunit-0.10.0.1-A8l0f8Sa1t1GLyHAXqb4Vv
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.
category: Testing
abi: 2305845b30d1cb2580f0b3c935f66b11
exposed: True
exposed-modules:
    Test.Tasty.HUnit
hidden-modules: Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs: /usr/lib/ghc-8.6.1/site-local/tasty-hunit-0.10.0.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/tasty-hunit-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/tasty-hunit-0.10.0.1
hs-libraries: HStasty-hunit-0.10.0.1-A8l0f8Sa1t1GLyHAXqb4Vv
depends:
    base-4.12.0.0 call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    tasty-1.1.0.4-KA2OQv2hxns8llKnTblJO9
haddock-interfaces: /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html: /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
